import type { AxiosInstance } from 'axios';

declare type Actions = 'c' | 'r' | 'u' | 'd' | 'getList' | 'updateStatus' | 'enable' | 'disable' | any;

export declare type D = (payload: any, payloadAs: PayloadAs) => Promise<unknown>;

export declare type Disable = (payload: any, payloadAs: PayloadAs) => Promise<unknown>;

export declare type Enable = (payload: any, payloadAs: PayloadAs) => Promise<unknown>;

export declare interface Form {
    status?: FormStatus;
    show?: boolean;
    data?: any;
    dataAt?: string | ((...args: any) => unknown) | symbol;
    mergeData?: MergeFormData;
    loading?: boolean;
    submitting?: boolean;
}

export declare type FormStatus = '' | 'c' | 'r' | 'u' | string;

export declare type GetList = (...args: any) => Promise<unknown> | void;

declare type _GetList = (payload: any, payloadAs?: PayloadAs) => Promise<any>;

export declare type GetListTrigger = 'init' | 'pageNumberChange' | 'filterChange' | 'c' | 'r' | 'u' | 'd' | 'updateStatus' | 'enable' | 'disable';

export declare function getValue<V = any>(object: V, path?: string | ((object: V) => unknown) | symbol): any;

export declare interface List {
    filter: Record<keyof any, any>;
    pageNumberAt: string;
    watchFilter?: boolean;
    debounceInterval?: number;
    data?: any[];
    dataAt?: string | ((...args: any) => unknown) | symbol;
    total?: number;
    totalAt?: string | ((...args: any) => unknown) | symbol;
    loading?: boolean;
}

export declare type MergeFormData = 'deep' | 'shallow' | false | ((newFormData: any) => any);

export declare type OpenForm = (...args: any) => Form | Promise<any> | undefined;

declare type _OpenForm = (payload: any, payloadAs?: PayloadAs | 'cache') => Promise<any> | undefined;

declare type PayloadAs = 'data' | 'params' | 'config' | undefined;

export declare function setValue<V = any>(object: V, path: string | ((object: V) => unknown) | symbol, value: any): any;

export declare type SubmitForm = (...args: any) => Form | Promise<any> | undefined;

declare type _SubmitForm = (params: any) => Promise<any>;

export declare type UpdateStatus = (payload: any, payloadAs: PayloadAs) => Promise<unknown>;

declare function useAdmate({ axios, axiosConfig, urlPrefix, form, list, getListProxy, openFormProxy, submitFormProxy, }: {
    axios: AxiosInstance;
    axiosConfig: Record<Actions, object | ((objForConfig: object) => object)>;
    urlPrefix: string;
    form?: Form;
    list?: List;
    getListProxy?: (getList: _GetList, trigger?: GetListTrigger) => void;
    openFormProxy?: (openForm: _OpenForm) => Promise<Form> | Form | undefined;
    submitFormProxy?: (submitForm: _SubmitForm) => Promise<Form> | Form | undefined;
}): {
    list: List;
    getList: GetList;
    form: Form;
    openForm: OpenForm;
    submitForm: SubmitForm;
    d: D;
    enable: Enable;
    disable: Disable;
    updateStatus: UpdateStatus;
};
export default useAdmate;

export { }
